# DOI Downloader

The DOI Downloader module provides functionality to download academic papers using their Digital Object Identifiers (DOIs).

## Features

- Download PDFs using DOI
- Batch download multiple DOIs
- Configurable delay between requests
- Email registration for better Crossref API service

## Usage

### Single DOI Download 